@@ -10,6 +10,8 @@ from labstep.entities.protocolVersion.model import ProtocolVersion
 import labstep.generic.entity.repository as entityRepository
 from labstep.service.htmlExport import htmlExportService
 from labstep.constants import UNSPECIFIED
+from labstep.config.export import includePDF
+from labstep.service.htmlToPDF import htmlToPDF
 
 
 def getProtocol(user, protocol_id):
@@ -83,8 +85,15 @@ def exportProtocol(protocol, root_path):
         dat.export(dataDir)
 
     # get html
-    html = htmlExportService.getHTML(protocol)
+    html = htmlExportService.getHTML(
+        protocol.last_version, withImages=includePDF)
     html_with_paths = htmlExportService.insertFilepaths(expDir, html)
 
-    with open(expDir.joinpath('entity.html'), 'w') as out:
+    with open(expDir.joinpath(f'{expDir.name}.html'), 'w') as out:
         out.write(html_with_paths)
+
+    # get pdf
+    if includePDF:
+        pdf = htmlToPDF(protocol.__user__, html_with_paths)
+        with open(expDir.joinpath(f'{expDir.name}.pdf'), 'wb') as out:
+            out.write(pdf)
