@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 # Author: Labstep <dev@labstep.com>
 
+from labstep.entities.resourceLocation.repository import getResourceLocation
 from labstep.generic.entity.model import Entity
 from labstep.service.helpers import getTime
 from labstep.constants import UNSPECIFIED
@@ -242,3 +243,73 @@ class ResourceItem(Entity):
         import labstep.entities.experimentDataField.repository as experimentDataFieldRepository
 
         return experimentDataFieldRepository.getDataFields(self)
+
+    def setLocation(self, resource_location_id, position=None, size=[1, 1]):
+        """
+        Set the location of the item and the position within the location.
+
+        Parameters
+        ----------
+        resource_location_id (int)
+            The id of location to put the item
+        position ([x: int,y: int])
+            Optional: The position within the location to set as [x,y] coordinates
+        size ([w: int,h: int])
+            Optional: Specify the width / height the item takes up in the location (defaults to [1,1])
+
+
+        Example
+        -------
+        ::
+
+            item = user.getResourceItem(17000)
+            location = user.getResourceLocation(12434)
+            item.setLocation(location,[1,3])
+        """
+        self.edit(resource_location_id=resource_location_id)
+
+        if position is not None:
+
+            from labstep.entities.resourceLocation.repository import setPosition
+            from labstep.entities.resourceLocation.model import ResourceLocation
+
+            setPosition(entity=self,
+                        location=ResourceLocation(
+                            {'id': resource_location_id}, self.__user__),
+                        position=position,
+                        size=size)
+
+    def getLocation(self):
+        """
+        Returns details on the location of the item as a dictionary of the form:
+
+
+        {
+            'resource_location': :class:`~labstep.entities.resourceLocation.model.ResourceLocation`,
+            'position': [x (int),y (int)],
+            'size': [w (int),h (int)]
+        }
+        """
+        from labstep.entities.resourceLocation.repository import getPosition
+
+        self.update()
+
+        if getattr(self, 'resource_location', None) is not None:
+
+            location = getResourceLocation(
+                self.__user__, self.resource_location['id'])
+
+            position = getPosition(self, location)
+
+            if position is None:
+                return {
+                    'resource_location': location,
+                    'position': None,
+                    'size': None
+                }
+
+            return {
+                'resource_location': location,
+                'position': [position['x'], position['y']],
+                'size': [position['w'], position['h']]
+            }
