@@ -197,3 +197,32 @@ def dataFrameToDataTable(df):
         df.columns), "colHeaderData": {}, "data": {"dataTable": {**headers, **dataTable}}}
 
     return data
+
+
+def linearToCartesianCoordinates(position, number_of_columns):
+
+    mod = position % number_of_columns
+    floor = position // number_of_columns
+
+    y = floor if mod != 0 else floor - 1
+    x = mod - 1 if mod != 0 else number_of_columns
+
+    return [x, y]
+
+
+def alphanumericToCartesianCoordinates(position):
+    from re import match as rematch
+
+    position = position.lower()
+
+    m = rematch('([a-z]+)([0-9]+)', position)
+
+    if m is None:
+        print('Invalid position: {}'.format(position))
+    else:
+        row = 0
+        for ch in m.group(1):
+            row += ord(ch) - 96
+        col = int(m.group(2))
+
+    return [col, row]
